%define		major		1.7
%define		libname		%mklibname openimageio %{major}
%define		develname	%mklibname openimageio -d

Name:		openimageio
Version:	1.7.14
Release:	%mkrel 3
Summary:	Library for reading and writing images
Group:		System/Libraries
License:	BSD
URL:		https://sites.google.com/site/openimageio/home
Source0:	https://github.com/OpenImageIO/oiio/archive/Release-%{version}.tar.xz
Patch0:		OpenImageIO-1.7.9-dl.patch
Patch1:		OpenImageIO-uninit.patch
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	giflib-devel
BuildRequires:	hdf5-devel
BuildRequires:	ilmbase-devel
BuildRequires:	libjpeg-devel
BuildRequires:	OpenEXR-devel
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(jasper)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libraw_r)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(OpenColorIO)
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(python2)
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pugixml-devel
BuildRequires:	lib64openjpeg-devel
BuildRequires:	qt4-devel
BuildRequires:	txt2man

Obsoletes:	OpenImageIO < %{version}

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. Main features include:
- Extremely simple but powerful ImageInput and ImageOutput APIs for reading and
  writing 2D images that is format agnostic.
- Format plugins for TIFF, JPEG/JFIF, OpenEXR, PNG, HDR/RGBE, Targa, JPEG-2000,
  DPX, Cineon, FITS, BMP, ICO, RMan Zfile, Softimage PIC, DDS, SGI,
  PNM/PPM/PGM/PBM, Field3d.
- An ImageCache class that transparently manages a cache so that it can access
  truly vast amounts of image data.
- A really nice image viewer, iv, also based on OpenImageIO classes (and so
  will work with any formats for which plugins are available).

%package -n %{libname}
Summary:	A library for reading and writing images
Group:		System/Libraries

%description -n %{libname}
OpenImageIO is a library for reading and writing images.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}OpenImageIO-devel
Provides:   %{_lib}OpenImageIO-devel = %{version}-%{release}

%description -n %{develname}
Development files for %{name} library.

%package -n python-%{name}
Summary:	Python 2 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python-OpenImageIO = %{version}-%{release}

%description -n python-%{name}
Python 2 bindings for %{name}.

%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python3-OpenImageIO = %{version}-%{release}

%description -n python3-%{name}
Python3 bindings for %{name}.

%prep
%setup -qn oiio-Release-%{version}
%apply_patches

# Remove bundled pugixml
rm -f src/include/OpenImageIO/pugixml.hpp \
      src/include/OpenImageIO/pugiconfig.hpp \
      src/include/OpenImageIO/pugixml.cpp

%build
%cmake -DUSE_OPENSSL:BOOL=ON \
       -DUSE_PYTHON:BOOL=ON \
       -DUSE_PYTHON3:BOOL=ON \
       -DPYLIB_INSTALL_DIR:PATH=%{python2_sitearch} \
       -DPYLIB3_INSTALL_DIR:PATH=%{python3_sitearch} \
       -DINCLUDE_INSTALL_DIR:PATH=%{_includedir}/OpenImageIO \
       -DMAN_INSTALL_DIR:PATH=%{_mandir}/man1 \
       -DDOC_INSTALL_DIR:PATH=%{_docdir}/OpenImageIO \
       -DSTOP_ON_WARNING=OFF \
       -DUSE_EXTERNAL_PUGIXML:BOOL=ON
%make_build

%install
rm -rf %buildroot
%make_install -C build

rm -fr %{buildroot}%{_docdir}

%files
%{_bindir}/*
%{_xfontdir}/oiio/
%{_mandir}/man1/*

%files -n %{libname}
%{_libdir}/libOpenImageIO.so.%{major}*
%{_libdir}/libOpenImageIO_Util.so.%{major}*

%files -n %{develname}
%doc CHANGES.md
%doc README.md
%doc src/doc/*.pdf
%doc LICENSE
%{_libdir}/libOpenImageIO.so
%{_libdir}/libOpenImageIO_Util.so
%dir %{_includedir}/OpenImageIO
%{_includedir}/OpenImageIO/*

%files -n python-%{name}
%{python2_sitearch}/OpenImageIO.so

%files -n python3-%{name}
#%{python3_sitearch}/OpenImageIO.so


%changelog
* Tue Sep 24 2017 bb2 <bb2> - 1.7.14-3pclos2017
- build with new openjpeg

* Wed Sep 20 2017 bb2 <bb2> - 1.7.14-2pclos2017
- rebuild new gcc and boost

* Wed Aug 23 2017 bb2 <bb2> - 1.7.14-1pclos2017
- new version
